Stan Math Library: stan/math/rev/scal/fun/fmod.hpp File Reference

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

Namespaces | Functions
fmod.hpp File Reference
`#include <stan/math/rev/core.hpp>`
`#include <boost/math/special_functions/fpclassify.hpp>`
`#include <cmath>`
`#include <limits>`

Go to the source code of this file.

## Namespaces
| stan
| stan::math
| Matrices and templated mathematical functions.

## Functions
var | stan::math::fmod (const var &a, const var &b)
| Return the floating point remainder after dividing the first variable by the second (cmath). More...
var | stan::math::fmod (const var &a, const double b)
| Return the floating point remainder after dividing the the first variable by the second scalar (cmath). More...
var | stan::math::fmod (const double a, const var &b)
| Return the floating point remainder after dividing the first scalar by the second variable (cmath). More...

[ Stan Home Page ] © 2011–2016, Stan Development Team.